#!/bin/bash
#
# Sends a job to a WN to make a glite-catalog-ls from there.
#
##########################################################################
#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://eu-egee.org/partners/ for details on the copyright holders.
# For license conditions see the license file 
# http://eu-egee.org/license.html
#
#########################################################################
# Author: David Collados
# $Id: test_catalog_ls_from_wn.sh,v 1.3 2005/04/29 12:32:58 dcollado Exp $
# 
#
# Usage: test_catalog_ls_from_wn.sh
#
###############################################################################
# Beginning of functions definitions
###############################################################################
#
function usage()
{
    cat <<EOF

usage: `basename $0` [-h]

Sends a job to a WN to make a glite-catalog-ls from there.
-h                   Print this message.

EOF
} 

###############################################################################
# End of function definitions
###############################################################################

###############################################################################
# Main program begins here!
###############################################################################

# Verbose and debug options are off by default
verbose=0
debug=0

#Parse command line options
while getopts h opt
do
   case "$opt" in
      h) usage
         exit 0
         ;;
   esac
done

# creating the jdl
cat <<EOF > catalog-ls.jdl
Executable = "$GLITE_LOCATION/bin/glite-catalog-ls";
Arguments="/";
StdOutput = "catalog-ls.out";
StdError = "catalog-ls.err";
OutputSandbox = {"catalog-ls.out","catalog-ls.err"};
Rank = -other.GlueCEPolicyMaxCPUTime;
RetryCount = 3;
EOF

#submit the job
echo "Submitting the job..."
glite-job-submit catalog-ls.jdl > /tmp/glite-job-submit.out
if [ $? -ne 0 ]; then
    echo "glite-job-submit catalog-ls.jdl > /tmp/glite-job-submit.out command failed. Exiting..."
    exit 2
fi


# Retrieve the job identifier
job=`grep http /tmp/glite-job-submit.out | cut -f 2 -d -`
echo "Job identifier is $job" 
echo ""

echo "Checking job status..."
echo "Calling: glite-job-status $job"
stat=2

# Do this till you reach the timeout or status will be Ready
count=0

while [ $stat -ne 0 -a $count -le 15 ]; do 
   let count=count+1
   glite-job-status $job > /tmp/glite-job-status.out
   status=`grep Current /tmp/glite-job-status.out | cut -f 2 -d : | sed "s/ //g"`
   echo "Current Status is: $status ..."
   echo $status | grep -i 'Done'
   if [ $? -eq 0 ]; then
       stat=0
       else
       stat=1
   fi
   echo "stat is " $stat
   rm -f /tmp/glite-job-status.out
   sleep 15
done

#Remove temporary file
rm -f /tmp/glite-job-submit.out

if [ $count -eq 10 ]; then
    exit 2
fi

if [ $stat -eq 0 ]; then 
    glite-job-output $job
fi

echo " "
exit 0;

