#!/bin/bash
#
# Script to use glite_put specifying an LFN of 800 chars length.
#
##########################################################################
#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://eu-egee.org/partners/ for details on the copyright holders.
# For license conditions see the license file 
# http://eu-egee.org/license.html
#
#########################################################################
# Author: David Collados
# $Id $
# 
#
# Usage: test_glite_put_lfn_800_chars.sh [-c config_file][-i input_file][-l lfn][-h]
#
# -c config_file       gLite IO client config file.
# -i input_file        Input file for the glite_put.
# -l lfn               LFN that will be used for the input file.
# -v                   Verbose.
# -h                   Usage.

###############################################################################
# Beginning of functions definitions
###############################################################################

function usage()
{
    cat <<EOF

usage: `basename $0` [-c config_file][-i input_file][-l lfn][-v][-h]

Try to put a file in a SE using glite_put and specifying an LFN of 800 chars length.

-c config_file       gLite IO config file.
-i input_file        Input file for the glite_put.
-l lfn               LFN that will be used for the input file.
-v                   Verbose.
-h                   Print this message.

EOF
} 

###############################################################################
# End of function definitions
###############################################################################

###############################################################################
# Main program begins here!
###############################################################################

# Verbose and debug options are off by default
verbose=0
debug=0
 
#Parse command line options
while getopts c:i:l:vh opt
do
   case "$opt" in
      c) CONFIG_FILE=$OPTARG
         if [ $verbose -eq 1 ]; then
            echo "Config file: " $CONFIG_FILE
         fi
         ;;
      i) INPUT_FILE=$OPTARG
         if [ $verbose -eq 1 ]; then 
            echo "Input file: " $INPUT_FILE
         fi
         ;;
      l) LFN=$OPTARG
         if [ $verbose -eq 1 ]; then
            echo "Lfn used: " $LFN
         fi
         ;;
      v) verbose=1
         ;;
      h) usage
         exit 0
         ;;
   esac
done

if [ -z "$CONFIG_FILE" ]; then
    echo "error: CONFIG_FILE not defined!"
    usage
    exit 1
fi

if [ -z "$INPUT_FILE" ]; then
    echo "error: INPUT_FILE not defined!"
    usage
    exit 1
fi

if [ -z "$LFN" ]; then
    echo "error: LFN not defined!"
    usage
    exit 1
fi

# GLITE_PUT the file
echo ""
echo "Calling: $GLITE_LOCATION/bin/glite-put -c $CONFIG_FILE $INPUT_FILE $LFN"
echo ""
$GLITE_LOCATION/bin/glite-put -c $CONFIG_FILE $INPUT_FILE $LFN
if [ $? -ne 0 ]; then
    echo "$GLITE_LOCATION/bin/glite-put -c $CONFIG_FILE $INPUT_FILE $LFN command failed. Exiting..."
    echo ""
    exit 2 
fi

exit 0;

